==> haskell-regex-1.1.0.2-57.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex
version:              1.1.0.2
visibility:           public
id:                   regex-1.1.0.2-BntKbU0q1PKAtrcOS2MysD
key:                  regex-1.1.0.2-BntKbU0q1PKAtrcOS2MysD
license:              BSD-3-Clause
copyright:            Chris Dornan 2016-2017
maintainer:           Chris Dornan <chris@regex.uk>
author:               Chris Dornan
stability:            Stable
homepage:             http://regex.uk
synopsis:             Toolkit for regex-base
description:
    A regular expression toolkit for regex-base with
    compile-time checking of RE syntax, data types for
    matches and captures, a text replacement toolkit,
    portable options, high-level AWK-like tools
    for building text processing apps, regular expression
    macros with parsers and test bench, comprehensive
    documentation, tutorials and copious examples.

category:             Text
abi:                  3e0c3510f62ed04db544d04296314388
exposed:              True
exposed-modules:
    Text.RE Text.RE.REOptions Text.RE.Replace Text.RE.Summa
    Text.RE.TDFA Text.RE.TDFA.ByteString Text.RE.TDFA.ByteString.Lazy
    Text.RE.TDFA.Sequence Text.RE.TDFA.String Text.RE.TDFA.Text
    Text.RE.TDFA.Text.Lazy Text.RE.TestBench Text.RE.TestBench.Parsers
    Text.RE.Tools Text.RE.Tools.Edit Text.RE.Tools.Find
    Text.RE.Tools.Grep Text.RE.Tools.IsRegex Text.RE.Tools.Lex
    Text.RE.Tools.Sed Text.RE.ZeInternals
    Text.RE.ZeInternals.Types.Poss

hidden-modules:
    Text.RE.ZeInternals.AddCaptureNames
    Text.RE.ZeInternals.EscapeREString
    Text.RE.ZeInternals.NamedCaptures Text.RE.ZeInternals.PreludeMacros
    Text.RE.ZeInternals.QQ Text.RE.ZeInternals.Replace
    Text.RE.ZeInternals.SearchReplace
    Text.RE.ZeInternals.SearchReplace.TDFA
    Text.RE.ZeInternals.SearchReplace.TDFA.ByteString
    Text.RE.ZeInternals.SearchReplace.TDFA.ByteString.Lazy
    Text.RE.ZeInternals.SearchReplace.TDFA.Sequence
    Text.RE.ZeInternals.SearchReplace.TDFA.String
    Text.RE.ZeInternals.SearchReplace.TDFA.Text
    Text.RE.ZeInternals.SearchReplace.TDFA.Text.Lazy
    Text.RE.ZeInternals.SearchReplace.TDFAEdPrime
    Text.RE.ZeInternals.TDFA Text.RE.ZeInternals.TestBench
    Text.RE.ZeInternals.TestBench.Parsers Text.RE.ZeInternals.Tools.Lex
    Text.RE.ZeInternals.Types.Capture
    Text.RE.ZeInternals.Types.CaptureID
    Text.RE.ZeInternals.Types.IsRegex Text.RE.ZeInternals.Types.LineNo
    Text.RE.ZeInternals.Types.Match Text.RE.ZeInternals.Types.Matches
    Text.RE.ZeInternals.Types.SearchReplace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex
hs-libraries:         HSregex-1.1.0.2-BntKbU0q1PKAtrcOS2MysD
depends:
    array-0.5.6.0 base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    containers-0.6.7 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-pcre-0.95.0.1-Cp22cHlfz6kFUZgDY8Q3Ru
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2 template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-regex/html/regex.haddock
haddock-html:         /usr/share/doc/haskell-regex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-1.1.0.2-58-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex
version:              1.1.0.2
visibility:           public
id:                   regex-1.1.0.2-C8EXxeYnO2XCcga8e4uHAy
key:                  regex-1.1.0.2-C8EXxeYnO2XCcga8e4uHAy
license:              BSD-3-Clause
copyright:            Chris Dornan 2016-2017
maintainer:           Chris Dornan <chris@regex.uk>
author:               Chris Dornan
stability:            Stable
homepage:             http://regex.uk
synopsis:             Toolkit for regex-base
description:
    A regular expression toolkit for regex-base with
    compile-time checking of RE syntax, data types for
    matches and captures, a text replacement toolkit,
    portable options, high-level AWK-like tools
    for building text processing apps, regular expression
    macros with parsers and test bench, comprehensive
    documentation, tutorials and copious examples.

category:             Text
abi:                  5dc9561a4e240af1a9885023d477cf61
exposed:              True
exposed-modules:
    Text.RE Text.RE.REOptions Text.RE.Replace Text.RE.Summa
    Text.RE.TDFA Text.RE.TDFA.ByteString Text.RE.TDFA.ByteString.Lazy
    Text.RE.TDFA.Sequence Text.RE.TDFA.String Text.RE.TDFA.Text
    Text.RE.TDFA.Text.Lazy Text.RE.TestBench Text.RE.TestBench.Parsers
    Text.RE.Tools Text.RE.Tools.Edit Text.RE.Tools.Find
    Text.RE.Tools.Grep Text.RE.Tools.IsRegex Text.RE.Tools.Lex
    Text.RE.Tools.Sed Text.RE.ZeInternals
    Text.RE.ZeInternals.Types.Poss

hidden-modules:
    Text.RE.ZeInternals.AddCaptureNames
    Text.RE.ZeInternals.EscapeREString
    Text.RE.ZeInternals.NamedCaptures Text.RE.ZeInternals.PreludeMacros
    Text.RE.ZeInternals.QQ Text.RE.ZeInternals.Replace
    Text.RE.ZeInternals.SearchReplace
    Text.RE.ZeInternals.SearchReplace.TDFA
    Text.RE.ZeInternals.SearchReplace.TDFA.ByteString
    Text.RE.ZeInternals.SearchReplace.TDFA.ByteString.Lazy
    Text.RE.ZeInternals.SearchReplace.TDFA.Sequence
    Text.RE.ZeInternals.SearchReplace.TDFA.String
    Text.RE.ZeInternals.SearchReplace.TDFA.Text
    Text.RE.ZeInternals.SearchReplace.TDFA.Text.Lazy
    Text.RE.ZeInternals.SearchReplace.TDFAEdPrime
    Text.RE.ZeInternals.TDFA Text.RE.ZeInternals.TestBench
    Text.RE.ZeInternals.TestBench.Parsers Text.RE.ZeInternals.Tools.Lex
    Text.RE.ZeInternals.Types.Capture
    Text.RE.ZeInternals.Types.CaptureID
    Text.RE.ZeInternals.Types.IsRegex Text.RE.ZeInternals.Types.LineNo
    Text.RE.ZeInternals.Types.Match Text.RE.ZeInternals.Types.Matches
    Text.RE.ZeInternals.Types.SearchReplace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex
hs-libraries:         HSregex-1.1.0.2-C8EXxeYnO2XCcga8e4uHAy
depends:
    array-0.5.6.0 base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    containers-0.6.7 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-pcre-0.95.0.1-Cp22cHlfz6kFUZgDY8Q3Ru
    regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-regex/html/regex.haddock
haddock-html:         /usr/share/doc/haskell-regex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
